## pySatellite
- Simulate satellite tracking.
- It tells the story of space debris and satellite collisions.
- To Infinity, and Beyond!

## use
[https://pysatellite.github.io/#use](https://pysatellite.github.io/#use)

## pypi
[https://pypi.org/project/pySatellite](https://pypi.org/project/pySatellite/)
